API docs for “spamfighter.core.counters.RequestPerSecondCounter”

# Class s.c.c.RequestPerSecondCounter(SpeedCounter):

Part of spamfighter.core.counters View Source View In Hierarchy

Счетчик числа запросов в секунду.

Method | __init__ | Конструктор.
Method | format | Строка формата для вывода значения счетчика.

Inherited from SpeedCounter:

Method | values | Получить значения счетчиков в виде массива значений.

Inherited from Counter (via SpeedCounter):

Method | increment | Увеличить значение счетчика на указанное значение.
Method | __str__ | Представить текущее состояние счетчика в понятном человеку виде.

def __init__(self): (source)
Конструктор.

def format(self): (source)
overrides spamfighter.core.counters.Counter.format
Строка формата для вывода значения счетчика.